# HG changeset patch
# User Alexander Smirnov <alexander@smirn0v.ru>
# Date 1586711851 0
#      Sun Apr 12 17:17:31 2020 +0000
# Node ID b30d88436de8aac736e1da5e7c8d592aeef70fe5
# Parent  681b78a98a5210d4369599e528ab0a682ac72a0d
Respect 'session_tickets off' config value for TLS 1.3

According to OpenSSL docs https://www.openssl.org/docs/man1.1.1/man3/SSL_get_options.html it is not enough to set SSL_OP_NO_TICKET for TLS 1.3 to disallow session tickets.
It will only disable stateless session tickets. To fully disable session tickets it is required to call SSL_CTX_set_num_tickets(ctx, 0).

diff -r 681b78a98a52 -r b30d88436de8 src/http/modules/ngx_http_ssl_module.c
--- a/src/http/modules/ngx_http_ssl_module.c	Wed Apr 08 01:02:17 2020 +0300
+++ b/src/http/modules/ngx_http_ssl_module.c	Sun Apr 12 17:17:31 2020 +0000
@@ -830,6 +830,9 @@
 #ifdef SSL_OP_NO_TICKET
     if (!conf->session_tickets) {
         SSL_CTX_set_options(conf->ssl.ctx, SSL_OP_NO_TICKET);
+#if OPENSSL_VERSION_NUMBER >= 0x1010104fL
+        SSL_CTX_set_num_tickets(conf->ssl.ctx, 0);
+#endif
     }
 #endif
 
diff -r 681b78a98a52 -r b30d88436de8 src/mail/ngx_mail_ssl_module.c
--- a/src/mail/ngx_mail_ssl_module.c	Wed Apr 08 01:02:17 2020 +0300
+++ b/src/mail/ngx_mail_ssl_module.c	Sun Apr 12 17:17:31 2020 +0000
@@ -449,6 +449,9 @@
 #ifdef SSL_OP_NO_TICKET
     if (!conf->session_tickets) {
         SSL_CTX_set_options(conf->ssl.ctx, SSL_OP_NO_TICKET);
+#if OPENSSL_VERSION_NUMBER >= 0x1010104fL
+        SSL_CTX_set_num_tickets(conf->ssl.ctx, 0);
+#endif
     }
 #endif
 
diff -r 681b78a98a52 -r b30d88436de8 src/stream/ngx_stream_ssl_module.c
--- a/src/stream/ngx_stream_ssl_module.c	Wed Apr 08 01:02:17 2020 +0300
+++ b/src/stream/ngx_stream_ssl_module.c	Sun Apr 12 17:17:31 2020 +0000
@@ -799,6 +799,9 @@
 #ifdef SSL_OP_NO_TICKET
     if (!conf->session_tickets) {
         SSL_CTX_set_options(conf->ssl.ctx, SSL_OP_NO_TICKET);
+#if OPENSSL_VERSION_NUMBER >= 0x1010104fL
+        SSL_CTX_set_num_tickets(conf->ssl.ctx, 0);
+#endif
     }
 #endif
 
